@@ -11,7 +11,7 @@ LightResponseCurveFitter <- setRefClass('LightResponseCurveFitter'
 
 #' @export
 LightResponseCurveFitter_getParameterNames <- function(
-	### return the parameter names used by this Light Response Curve Funciton
+	### return the parameter names used by this Light Response Curve Function
 ) {
 	# if this method is adjusted in subclass
 	# , then also adjust getPriorLocation, getPriorScale
@@ -228,7 +228,7 @@ LightResponseCurveFitter_getParameterInitials <- function(
 		### return the prior distribution of parameters
 		thetaPrior 	##<< numeric vector prior estimate of parameters
 ) {
-	# only beta (second parameter)  is varied between different intial guesses
+	# only beta (second parameter)  is varied between different initial guesses
 	##value<< a numeric matrix (3, nPar) of initial values for fitting parameters
 	thetaInitials <- matrix(rep(thetaPrior, each = 3), 3, length(thetaPrior)
 	                        , dimnames = list(NULL, names(thetaPrior)))
@@ -257,7 +257,7 @@ LightResponseCurveFitter_optimLRCBounds <- function(
 	isUsingFixedVPD <- isNeglectVPDEffect
 	isUsingFixedAlpha <- FALSE
 	getIOpt <- .self$getOptimizedParameterPositions
-	theta0Adj <- theta0	# intial estimate with some parameters adjusted to bounds
+	theta0Adj <- theta0	# initial estimate with some parameters adjusted to bounds
 	if (isNeglectVPDEffect) theta0Adj[1] <- 0
 	resOpt <- resOpt0 <- .self$optimLRCOnAdjustedPrior(theta0Adj, iOpt =
         getIOpt(isUsingFixedVPD, isUsingFixedAlpha)
@@ -386,76 +386,80 @@ LightResponseCurveFitter_optimLRCOnAdjustedPrior = function(
 		### Lower bound flux uncertainty and adjust prior uncertainty before calling optimLRC
 		theta  					##<< numeric vector of starting values
 		, iOpt					##<< integer vector: positions of subset of parameters
-		  ## that are optimized
+		## that are optimized
 		, dsDay					##<< dataframe of NEE, sdNEE and predictors Rg, VPD and Temp
 		, parameterPrior		##<< numeric vector of prior parameter estimates
-		  ## (corresponding to theta) # TODO rename to thetaPrior
+		## (corresponding to theta) # TODO rename to thetaPrior
 		, ctrl					##<< list of further controls
 		, ...					##<< further arguments to
-		  ## \code{\link{LightResponseCurveFitter_optimLRC}}
-		  ## (passed to \code{\link{LightResponseCurveFitter_computeCost}})
+		## \code{\link{LightResponseCurveFitter_optimLRC}}
+		## (passed to \code{\link{LightResponseCurveFitter_computeCost}})
 ) {
-	if (!all(is.finite(theta))) stop("need to provide finite starting values.")
-	##details<<
-	## Only those records are used for optimization where both NEE
-	## and sdNEE are finite.
-	## In larger settings, already filtered at
-	dsDayFinite <- dsDay[is.finite(dsDay$NEE) & is.finite(dsDay$sdNEE), ]
-	if (nrow(dsDayFinite) < ctrl$minNRecInDayWindow) {
-		stop("inspect too few records, should be already filtered "
-		     ,"in partGLFitLRCOneWindow")
-	 	return(list(
-				theta = {theta[] <- NA; theta}
-				, iOpt = integer(0)
-				, convergence = 1003L
-		))
-	}
-	##details<< Optimization of LRC parameters takes into account the uncertainty
-	##of the flux values. In order to avoid very strong leverage, values with a
-	##very low uncertainty (< a lower quantile) are assigned the lower quantile is
-	##assigned. This procedure downweighs records with a high uncertainty, but does
-	##not apply a large leverage for records with a very low uncertainty. Avoid
-	##this correction by setting \code{ctrl$isBoundLowerNEEUncertainty =
-	##FALSE}
-	Fc_unc <- if (isTRUE(ctrl$isBoundLowerNEEUncertainty) ) {
-	    #twutz: avoid excessive weights by small uncertainties (of 1 / unc^2)
-				pmax(dsDayFinite$sdNEE, quantile(dsDayFinite$sdNEE, 0.3) )
-			} else {
-				dsDayFinite$sdNEE
-			}
-	#plot(Fc_unc ~ dsDayFinite$sdNEE)
-	medianRelFluxUncertainty <- abs(median(Fc_unc / dsDayFinite$NEE))
-	##details<<
-	## The uncertainty of the prior, that maybe derived from fluxes)  is allowed to
-	## adapt to the uncertainty of the fluxes.
-	## This is done in \code{link{LightResponseCurveFitter_getPriorScale}}
-	sdParameterPrior <- .self$getPriorScale(parameterPrior, medianRelFluxUncertainty
-	                                        , nrow(dsDayFinite), ctrl = ctrl)
-	sdParameterPrior[-iOpt] <- NA
-	isUsingHessian <- (ctrl$nBootUncertainty == 0L)
-	.self$optimLRC(theta
-			, iOpt = iOpt
-			, flux = -dsDayFinite$NEE
-			, sdFlux = Fc_unc
-			, sdParameterPrior = sdParameterPrior
-			, parameterPrior = parameterPrior
-			, Rg = dsDayFinite$Rg
-			, VPD = dsDayFinite$VPD
-			, Temp = dsDayFinite$Temp
-			, isUsingHessian = isUsingHessian
-			, ctrl = ctrl
-	)
-	##value<< result of \code{\link{LightResponseCurveFitter_optimLRC}} with
-	## items theta, iOpt and convergence
+  if (!all(is.finite(theta))) stop("need to provide finite starting values.")
+  ##details<<
+  ## Only those records are used for optimization where both NEE
+  ## and sdNEE are finite.
+  ## In larger settings, already filtered at
+  dsDayFinite <- dsDay[is.finite(dsDay$NEE) & is.finite(dsDay$sdNEE), ]
+  if (nrow(dsDayFinite) < ctrl$minNRecInDayWindow) {
+    stop("inspect too few records, should be already filtered "
+         ,"in partGLFitLRCOneWindow")
+    return(list(
+      theta = {theta[] <- NA; theta}
+      , iOpt = integer(0)
+      , convergence = 1003L
+    ))
+  }
+  ##details<< Optimization of LRC parameters takes into account the uncertainty
+  ##of the flux values. In order to avoid very strong leverage, values with a
+  ##very low uncertainty (< a lower quantile) are assigned the lower quantile is
+  ##assigned. This procedure downweighs records with a high uncertainty, but does
+  ##not apply a large leverage for records with a very low uncertainty. Avoid
+  ##this correction by setting \code{ctrl$isBoundLowerNEEUncertainty =
+  ##FALSE}
+  minUnc <- quantile(dsDayFinite$sdNEE, 0.3)
+  if (minUnc == 0) stop(
+    "Too many zeros in uncertainty of NEE.",
+    " This cannot be handled in daytime partitioning.")
+  Fc_unc <- if (isTRUE(ctrl$isBoundLowerNEEUncertainty) ) {
+    #twutz: avoid excessive weights by small uncertainties (of 1 / unc^2)
+    pmax(dsDayFinite$sdNEE, minUnc )
+  } else {
+    dsDayFinite$sdNEE
+  }
+  #plot(Fc_unc ~ dsDayFinite$sdNEE)
+  medianRelFluxUncertainty <- abs(median(Fc_unc / dsDayFinite$NEE))
+  ##details<<
+  ## The uncertainty of the prior, that maybe derived from fluxes)  is allowed to
+  ## adapt to the uncertainty of the fluxes.
+  ## This is done in \code{link{LightResponseCurveFitter_getPriorScale}}
+  sdParameterPrior <- .self$getPriorScale(parameterPrior, medianRelFluxUncertainty
+                                          , nrow(dsDayFinite), ctrl = ctrl)
+  sdParameterPrior[-iOpt] <- NA
+  isUsingHessian <- (ctrl$nBootUncertainty == 0L)
+  .self$optimLRC(theta
+                 , iOpt = iOpt
+                 , flux = -dsDayFinite$NEE
+                 , sdFlux = Fc_unc
+                 , sdParameterPrior = sdParameterPrior
+                 , parameterPrior = parameterPrior
+                 , Rg = dsDayFinite$Rg
+                 , VPD = dsDayFinite$VPD
+                 , Temp = dsDayFinite$Temp
+                 , isUsingHessian = isUsingHessian
+                 , ctrl = ctrl
+  )
+  ##value<< result of \code{\link{LightResponseCurveFitter_optimLRC}} with
+  ## items theta, iOpt and convergence
 }
 LightResponseCurveFitter$methods(optimLRCOnAdjustedPrior =
-                          LightResponseCurveFitter_optimLRCOnAdjustedPrior)
+                                   LightResponseCurveFitter_optimLRCOnAdjustedPrior)
 
 
 #' @export
 LightResponseCurveFitter_isParameterInBounds <- function(
-		### Check if estimated parameter vector is within reasonable bounds
-		theta					##<< estimate of parameter
+  ### Check if estimated parameter vector is within reasonable bounds
+  theta					##<< estimate of parameter
 		, sdTheta			##<< estimate of uncertainty of the parameter
 		, RRefNight		##<< numeric scalar: night-time based estimate of
 		  ## basal respiration
@@ -639,7 +643,7 @@ LightResponseCurveFitter_computeLRCGradient <- function(
 		  ## [umol / m2 / s] or Global Radiation
 		, VPD 	##<< VPD [numeric] -> Vapor Pressure Deficit [hPa]
 		, Temp 	##<< Temp [degC] -> Temperature [degC]
-		, VPD0 = 10 			##<< VPDQ0 [hPa] -> Parameters VPD0 fixed to 10
+		, VPD0 = 10 			##<< VPD0 [hPa] -> Parameters VPD0 fixed to 10
 		  ## hPa according to Lasslop et al 2010
 		, fixVPD = (k == 0)   	##<< boolean scalar or vector of nrow(theta):
 		  ## fixVPD if TRUE the VPD effect is not considered and VPD is not part
